diff src/xterm.h @ 36254:f64eaa8f61aa

(struct x_output): Rename busy_cursor to hourglass_cursor, busy_window to hourglass_window, busy_p to hourglass_p.
author Gerd Moellmann <gerd@gnu.org>
date Wed, 21 Feb 2001 13:56:29 +0000
parents ff5045d1af58
children 1879cd230f9c
line wrap: on
line diff
--- a/src/xterm.h	Wed Feb 21 13:56:00 2001 +0000
+++ b/src/xterm.h	Wed Feb 21 13:56:29 2001 +0000
@@ -487,15 +487,15 @@
   Cursor nontext_cursor;
   Cursor modeline_cursor;
   Cursor cross_cursor;
-  Cursor busy_cursor;
+  Cursor hourglass_cursor;
   Cursor horizontal_drag_cursor;
 
-  /* Window whose cursor is busy_cursor.  This window is temporarily
-     mapped to display a busy-cursor.  */
-  Window busy_window;
+  /* Window whose cursor is hourglass_cursor.  This window is temporarily
+     mapped to display an hourglass cursor.  */
+  Window hourglass_window;
   
-  /* Non-zero means busy cursor is currently displayed.  */
-  unsigned busy_p : 1;
+  /* Non-zero means hourglass cursor is currently displayed.  */
+  unsigned hourglass_p : 1;
 
   /* Flag to set when the X window needs to be completely repainted.  */
   int needs_exposure;